==> kdebase-3.1.tar.bz2: kdebase-3.1/kate/interfaces/pluginconfiginterfaceextension.cpp <==
/* This file is part of the KDE libraries
   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// $Id: pluginconfiginterfaceextension.cpp,v 1.2 2002/06/05 21:42:15 cullmann Exp $

#include "pluginconfiginterfaceextension.h"
#include "pluginconfiginterfaceextension.moc"

#include "plugin.h"

namespace Kate
{

class PrivatePluginConfigInterfaceExtension
{
  public:
    PrivatePluginConfigInterfaceExtension() {}
     ~PrivatePluginConfigInterfaceExtension() {}
};

};

using namespace Kate;

PluginConfigPage::PluginConfigPage ( QWidget *parent, const char *name ) : QWidget (parent, name) { ; };
 
PluginConfigPage::~PluginConfigPage () { ; };

unsigned int PluginConfigInterfaceExtension::globalPluginConfigInterfaceExtensionNumber = 0;

PluginConfigInterfaceExtension::PluginConfigInterfaceExtension()
{
  globalPluginConfigInterfaceExtensionNumber++;
  myPluginConfigInterfaceExtensionNumber = globalPluginConfigInterfaceExtensionNumber++;

  d = new PrivatePluginConfigInterfaceExtension();
}

PluginConfigInterfaceExtension::~PluginConfigInterfaceExtension()
{
  delete d;
}

unsigned int PluginConfigInterfaceExtension::pluginConfigInterfaceExtensionNumber () const
{
  return myPluginConfigInterfaceExtensionNumber;
}
                      
PluginConfigInterfaceExtension *Kate::pluginConfigInterfaceExtension (Plugin *plugin)
{                       
  if (!plugin)
    return 0;

  return static_cast<PluginConfigInterfaceExtension*>(plugin->qt_cast("Kate::PluginConfigInterfaceExtension"));
}

==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kate/interfaces/pluginconfiginterfaceextension.cpp <==
/* This file is part of the KDE libraries
   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// $Id: pluginconfiginterfaceextension.cpp,v 1.2.2.1 2003/07/15 21:33:03 mueller Exp $

#include "pluginconfiginterfaceextension.h"
#include "pluginconfiginterfaceextension.moc"

#include "plugin.h"

namespace Kate
{

class PrivatePluginConfigInterfaceExtension
{
  public:
    PrivatePluginConfigInterfaceExtension() {}
     ~PrivatePluginConfigInterfaceExtension() {}
};

}

using namespace Kate;

PluginConfigPage::PluginConfigPage ( QWidget *parent, const char *name ) : QWidget (parent, name) { }
 
PluginConfigPage::~PluginConfigPage () { }

unsigned int PluginConfigInterfaceExtension::globalPluginConfigInterfaceExtensionNumber = 0;

PluginConfigInterfaceExtension::PluginConfigInterfaceExtension()
{
  globalPluginConfigInterfaceExtensionNumber++;
  myPluginConfigInterfaceExtensionNumber = globalPluginConfigInterfaceExtensionNumber++;

  d = new PrivatePluginConfigInterfaceExtension();
}

PluginConfigInterfaceExtension::~PluginConfigInterfaceExtension()
{
  delete d;
}

unsigned int PluginConfigInterfaceExtension::pluginConfigInterfaceExtensionNumber () const
{
  return myPluginConfigInterfaceExtensionNumber;
}
                      
PluginConfigInterfaceExtension *Kate::pluginConfigInterfaceExtension (Plugin *plugin)
{                       
  if (!plugin)
    return 0;

  return static_cast<PluginConfigInterfaceExtension*>(plugin->qt_cast("Kate::PluginConfigInterfaceExtension"));
}
